@@ -6,6 +6,8 @@ angular.module('contactsApp')
 
 	ctrl.contactList = [];
 	ctrl.searchTerm = '';
+	ctrl.show = true;
+	ctrl.invalid = false;
 
 	ctrl.t = {
 		addContact : t('contacts', 'Add contact'),
@@ -25,7 +27,6 @@ angular.module('contactsApp')
 		}
 		if (ev.event === 'changeSearch') {
 			ctrl.searchTerm = ev.searchTerm;
-			ctrl.t.emptySearch;
 			ctrl.t.emptySearch = t('contacts',
 								   'No search result for {query}',
 								   {query: ctrl.searchTerm}
@@ -66,19 +67,45 @@ angular.module('contactsApp')
 		});
 	});
 
+	// Get contacts
 	ContactService.getAll().then(function(contacts) {
-		$scope.$apply(function() {
-			ctrl.contacts = contacts;
-			if (!_.isEmpty(ctrl.contacts)) {
-				ctrl.setSelectedId(_.sortBy(contacts, function(contact) {
-					return contact.fullName();
-				})[0].uid());
-			}
+		if(contacts.length>0) {
+			$scope.$apply(function() {
+				ctrl.contacts = contacts;
+			});
+		} else {
 			ctrl.loading = false;
-		});
+		}
 	});
 
-	$scope.$watch('ctrl.routeParams.uid', function(newValue) {
+	// Wait for ctrl.contactList to be updated, load the first contact and kill the watch
+	var unbindListWatch = $scope.$watch('ctrl.contactList', function() {
+		if(ctrl.contactList && ctrl.contactList.length > 0) {
+			// Check if a specific uid is requested
+			if($routeParams.uid && $routeParams.gid) {
+				ctrl.contactList.forEach(function(contact) {
+					if(contact.uid() === $routeParams.uid) {
+						ctrl.setSelectedId($routeParams.uid);
+						ctrl.loading = false;
+					}
+				});
+			}
+			// No contact previously loaded, let's load the first of the list if not in mobile mode
+			if(ctrl.loading && $(window).width() > 768) {
+				ctrl.setSelectedId(ctrl.contactList[0].uid());
+			}
+			ctrl.loading = false;
+			unbindListWatch();
+		}
+	});
+
+	$scope.$watch('ctrl.routeParams.uid', function(newValue, oldValue) {
+		// Used for mobile view to clear the url
+		if(typeof oldValue != 'undefined' && typeof newValue == 'undefined' && $(window).width() <= 768) {
+			// no contact selected
+			ctrl.show = true;
+			return;
+		}
 		if(newValue === undefined) {
 			// we might have to wait until ng-repeat filled the contactList
 			if(ctrl.contactList && ctrl.contactList.length > 0) {
@@ -98,27 +125,33 @@ angular.module('contactsApp')
 					unbindWatch(); // unbind as we only want one update
 				});
 			}
+		} else {
+			// displaying contact details
+			ctrl.show = false;
 		}
 	});
 
 	$scope.$watch('ctrl.routeParams.gid', function() {
 		// we might have to wait until ng-repeat filled the contactList
 		ctrl.contactList = [];
-		// watch for next contactList update
-		var unbindWatch = $scope.$watch('ctrl.contactList', function() {
-			if(ctrl.contactList && ctrl.contactList.length > 0) {
-				$route.updateParams({
-					gid: $routeParams.gid,
-					uid: ctrl.contactList[0].uid()
-				});
-			} else {
-				$route.updateParams({
-					gid: $routeParams.gid,
-					uid: undefined
-				});
-			}
-			unbindWatch(); // unbind as we only want one update
-		});
+		// not in mobile mode
+		if($(window).width() > 768) {
+			// watch for next contactList update
+			var unbindWatch = $scope.$watch('ctrl.contactList', function() {
+				if(ctrl.contactList && ctrl.contactList.length > 0) {
+					$route.updateParams({
+						gid: $routeParams.gid,
+						uid: ctrl.contactList[0].uid()
+					});
+				}
+				unbindWatch(); // unbind as we only want one update
+			});
+		}
+	});
+
+	// Watch if we have an invalid contact
+	$scope.$watch('ctrl.contactList[0].displayName()', function(displayName) {
+		ctrl.invalid = (displayName === '');
 	});
 
 	ctrl.createContact = function() {
