@@ -8,18 +8,17 @@
  * @copyright Hendrik Leppelsack 2015
  */
 
-var app = angular.module('contactsApp', ['uuid4', 'angular-cache', 'ngRoute', 'ui.bootstrap', 'ui.select', 'ngSanitize']);
+angular.module('contactsApp', ['uuid4', 'angular-cache', 'ngRoute', 'ui.bootstrap', 'ui.select', 'ngSanitize'])
+.config(function($routeProvider) {
 
-app.config(['$routeProvider', function($routeProvider){
-
-	$routeProvider.when("/:gid", {
+	$routeProvider.when('/:gid', {
 		template: '<contactdetails></contactdetails>'
 	});
 
-	$routeProvider.when("/:gid/:uid", {
+	$routeProvider.when('/:gid/:uid', {
 		template: '<contactdetails></contactdetails>'
 	});
 
-	$routeProvider.otherwise("/" + t('contacts', 'All contacts'));
+	$routeProvider.otherwise('/' + t('contacts', 'All contacts'));
 
-}]);
+});
