@@ -19,6 +19,10 @@ angular.module('contactsApp')
 				}
 			},
 
+			displayName: function() {
+				return this.fullName() || this.org() || '';
+			},
+
 			fullName: function(value) {
 				var model = this;
 				if (angular.isDefined(value)) {
@@ -29,9 +33,12 @@ angular.module('contactsApp')
 					var property = model.getProperty('fn');
 					if(property) {
 						return property.value;
-					} else {
-						return undefined;
 					}
+					property = model.getProperty('n');
+					if(property) {
+						return property.value.join();
+					}
+					return undefined;
 				}
 			},
 
@@ -159,9 +166,17 @@ angular.module('contactsApp')
 				var matchingProps = ['fn', 'title', 'org', 'email', 'nickname', 'note', 'url', 'cloud', 'adr', 'impp', 'tel'].filter(function (propName) {
 					if (model.props[propName]) {
 						return model.props[propName].filter(function (property) {
-							if (property.value && _.isString(property.value)) {
+							if (!property.value) {
+								return false;
+							}
+							if (_.isString(property.value)) {
 								return property.value.toLowerCase().indexOf(pattern.toLowerCase()) !== -1;
 							}
+							if (_.isArray(property.value)) {
+								return property.value.filter(function(v) {
+									return v.toLowerCase().indexOf(pattern.toLowerCase()) !== -1;
+								}).length > 0;
+							}
 							return false;
 						}).length > 0;
 					}
