@@ -32,8 +32,13 @@ angular.module('contactsApp')
 					promises.push(
 						AddressBookService.sync(addressBook).then(function (addressBook) {
 							for (var i in addressBook.objects) {
-								var contact = new Contact(addressBook, addressBook.objects[i]);
-								contacts.put(contact.uid(), contact);
+								if (addressBook.objects[i].addressData) {
+									var contact = new Contact(addressBook, addressBook.objects[i]);
+									contacts.put(contact.uid(), contact);
+								} else {
+									// custom console
+									console.log('Invalid contact received: ' + addressBook.objects[i].url);
+								}
 							}
 						})
 					);
@@ -76,10 +81,15 @@ angular.module('contactsApp')
 		}
 	};
 
-	this.create = function(newContact, addressBook) {
+	this.create = function(newContact, addressBook, uid) {
 		addressBook = addressBook || AddressBookService.getDefaultAddressBook();
 		newContact = newContact || new Contact(addressBook);
-		var newUid = uuid4.generate();
+		var newUid = '';
+		if(uuid4.validate(uid)) {
+			newUid = uid;
+		} else {
+			newUid = uuid4.generate();
+		}
 		newContact.uid(newUid);
 		newContact.setUrl(addressBook, newUid);
 		newContact.addressBookId = addressBook.displayName;
@@ -100,17 +110,24 @@ angular.module('contactsApp')
 		});
 	};
 
-	this.import = function(data, type, addressBook) {
+	this.import = function(data, type, addressBook, progressCallback) {
 		addressBook = addressBook || AddressBookService.getDefaultAddressBook();
 
 		if(type === 'text/vcard') {
 			var regexp = /BEGIN:VCARD[\s\S]*?END:VCARD/mgi;
 			var singleVCards = data.match(regexp);
 
+			var num = 1;
 			for(var i in singleVCards) {
 				var newContact = new Contact(addressBook, {addressData: singleVCards[i]});
-				this.create(newContact, addressBook);
+				this.create(newContact, addressBook).then(function() {
+					// Update the progress indicator
+					if (progressCallback) progressCallback(num/singleVCards.length);
+					num++;
+				});
 			}
+		} else {
+			OC.Notification.showTemporary(t('contacts', 'Invalid file type.'));
 		}
 	};
 
@@ -120,12 +137,13 @@ angular.module('contactsApp')
 		}
 		contact.syncVCard();
 		var clone = angular.copy(contact);
+		var uid = contact.uid();
+
+		// delete the old one before to avoid conflict
+		this.delete(contact);
 
 		// create the contact in the new target addressbook
-		this.create(clone, addressbook);
-
-		// delete the old one
-		this.delete(contact);
+		this.create(clone, addressbook, uid);
 	};
 
 	this.update = function(contact) {
@@ -135,6 +153,7 @@ angular.module('contactsApp')
 		return DavClient.updateCard(contact.data, {json: true}).then(function(xhr) {
 			var newEtag = xhr.getResponseHeader('ETag');
 			contact.setETag(newEtag);
+			notifyObservers('update', contact.uid());
 		});
 	};
 
