@@ -1,7 +1,8 @@
-app.service('SettingsService', function() {
+angular.module('contactsApp')
+.service('SettingsService', function() {
 	var settings = {
 		addressBooks: [
-			"testAddr"
+			'testAddr'
 		]
 	};
 
