@@ -8,18 +8,21 @@ OC.L10N.register(
     "Organization" : "Organisation",
     "Title" : "Titel",
     "Add field ..." : "Feld hinzufügen ...",
+    "Import" : "Importieren",
     "Add contact" : "Kontakt hinzufügen",
     "No search result for {query}" : "Kein Ergebnis für {query}",
     "All contacts" : "Alle Kontakte",
     "Not grouped" : "Nicht gruppiert",
-    "Post Office Box" : "Briefkasten",
+    "Post Office Box" : "Postfach",
     "Postal Code" : "Postleitzahl",
     "City" : "Stadt",
     "State or province" : "Staat oder Provinz",
     "Country" : "Land",
     "Address" : "Adresse",
     "(new group)" : "(neue Gruppe)",
+    "New contact" : "Neuer Kontakt",
     "{addressbook} shared by {owner}" : "{addressbook} geteilt von {owner}",
+    "Invalid file type." : "Ungültiger Dateityp.",
     "Nickname" : "Spitzname",
     "Notes" : "Notizen",
     "Website" : "Website",
@@ -38,7 +41,7 @@ OC.L10N.register(
     "Fax work" : "Fax geschäftlich",
     "Pager" : "Pager",
     "Voice" : "Anruf",
-    "Settings" : "Einstellungen",
-    "Import" : "Importieren"
+    "Social Network" : "Soziales Netzwerk",
+    "Settings" : "Einstellungen"
 },
 "nplurals=2; plural=(n != 1);");
