@@ -2,12 +2,15 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontaktid",
+    "Address book name" : "Aadressiraamatu nimi",
     "No contacts in here" : "Ühtegi kontakti pole",
     "Name" : "Nimi",
     "Organization" : "Organisatsioon",
     "Title" : "Pealkiri",
     "Add field ..." : "Lisa väli ...",
+    "Import" : "Impordi",
     "Add contact" : "Lisa kontakt",
+    "No search result for {query}" : "Otsingutulemused sõnadele {query}",
     "All contacts" : "Kõik kontaktid",
     "Not grouped" : "Pole grupeeritud",
     "Post Office Box" : "Postkast postkontoris",
@@ -17,6 +20,7 @@ OC.L10N.register(
     "Country" : "Riik",
     "Address" : "Aadress",
     "(new group)" : "(uus grupps)",
+    "New contact" : "Uus kontakt",
     "{addressbook} shared by {owner}" : "{owner} jagas aadressiraamatut {addressbook}",
     "Nickname" : "Hüüdnimi",
     "Notes" : "Märkmed",
@@ -35,7 +39,6 @@ OC.L10N.register(
     "Fax work" : "Faks tööl",
     "Pager" : "Piipar",
     "Voice" : "Hääl",
-    "Settings" : "Seaded",
-    "Import" : "Impordi"
+    "Settings" : "Seaded"
 },
 "nplurals=2; plural=(n != 1);");
