@@ -2,11 +2,13 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contacts",
+    "Address book name" : "Nom du carnet d'adresses",
     "No contacts in here" : "Aucun contact",
     "Name" : "Nom",
     "Organization" : "Société",
     "Title" : "Titre",
     "Add field ..." : "Ajouter un champ ...",
+    "Import" : "Importer",
     "Add contact" : "Ajouter un contact",
     "No search result for {query}" : "Aucun résultat pour {query}",
     "All contacts" : "Tous les contacts",
@@ -18,7 +20,9 @@ OC.L10N.register(
     "Country" : "Pays",
     "Address" : "Adresse",
     "(new group)" : "(nouveau groupe)",
+    "New contact" : "Nouveau contact",
     "{addressbook} shared by {owner}" : "{addressbook} partagé par {owner}",
+    "Invalid file type." : "Type de fichier invalide.",
     "Nickname" : "Surnom",
     "Notes" : "Notes",
     "Website" : "Site web",
@@ -37,7 +41,7 @@ OC.L10N.register(
     "Fax work" : "Fax pro",
     "Pager" : "Bipeur",
     "Voice" : "Voix",
-    "Settings" : "Paramètres",
-    "Import" : "Importer"
+    "Social Network" : "Réseau Social",
+    "Settings" : "Paramètres"
 },
 "nplurals=2; plural=(n > 1);");
