@@ -2,11 +2,13 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Tengiliðir",
+    "Address book name" : "Heiti nafnaskrár",
     "No contacts in here" : "Engir tengiliðir hér",
     "Name" : "Nafn",
     "Organization" : "Stofnun/félag",
     "Title" : "Titill",
     "Add field ..." : "Bæta við reit...",
+    "Import" : "Flytja inn",
     "Add contact" : "Bæta við tengilið",
     "No search result for {query}" : "Engar leitarniðurstöður fyrir {query}",
     "All contacts" : "Allir tengiliðir",
@@ -18,6 +20,7 @@ OC.L10N.register(
     "Country" : "Land",
     "Address" : "Slóð",
     "(new group)" : "(nýr hópur)",
+    "New contact" : "Nýr tengiliður",
     "{addressbook} shared by {owner}" : "{addressbook} deilt af {owner}",
     "Nickname" : "Gælunafn",
     "Notes" : "Minnispunktar",
@@ -37,7 +40,6 @@ OC.L10N.register(
     "Fax work" : "Vinnufax",
     "Pager" : "Símboði",
     "Voice" : "Raddskilaboð",
-    "Settings" : "Stillingar",
-    "Import" : "Flytja inn"
+    "Settings" : "Stillingar"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
