@@ -7,6 +7,7 @@ OC.L10N.register(
     "Organization" : "조직",
     "Title" : "제목",
     "Add field ..." : "필드 추가...",
+    "Import" : "가져오기",
     "Add contact" : "연락처 추가",
     "All contacts" : "모든 연락처",
     "Not grouped" : "그룹에 없음",
@@ -16,6 +17,7 @@ OC.L10N.register(
     "State or province" : "도 및 광역시",
     "Country" : "국가",
     "Address" : "주소",
+    "New contact" : "새 연락처",
     "{addressbook} shared by {owner}" : "{owner} 님이 공유한 {addressbook}",
     "Nickname" : "별명",
     "Notes" : "메모",
@@ -33,7 +35,6 @@ OC.L10N.register(
     "Fax" : "팩스 번호",
     "Pager" : "호출기",
     "Voice" : "음성 번호",
-    "Settings" : "설정",
-    "Import" : "가져오기"
+    "Settings" : "설정"
 },
 "nplurals=1; plural=0;");
