@@ -7,6 +7,7 @@ OC.L10N.register(
     "Organization" : "Organizacja",
     "Title" : "Tytuł",
     "Add field ..." : "Dodaj pole ...",
+    "Import" : "Importuj",
     "Add contact" : "Dodaj kontakt",
     "No search result for {query}" : "Brak wyników wyszukiwania dla zapytania {query}",
     "All contacts" : "Wszystkie kontakty",
@@ -18,6 +19,7 @@ OC.L10N.register(
     "Country" : "Kraj",
     "Address" : "Adres",
     "(new group)" : "Nowa grupa",
+    "New contact" : "Nowy kontakt",
     "{addressbook} shared by {owner}" : "Książka {addressbook} udostępniona przez {owner}",
     "Nickname" : "Nazwa",
     "Notes" : "Notatki",
@@ -36,7 +38,6 @@ OC.L10N.register(
     "Fax work" : "Fakx pracowy",
     "Pager" : "Pager",
     "Voice" : "Połączenie głosowe",
-    "Settings" : "Ustawienia",
-    "Import" : "Importuj"
+    "Settings" : "Ustawienia"
 },
 "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
